@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2010 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2013 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -23,13 +23,13 @@
  *  always be made to wrapperinfo.c.in.
  */
 
-TCHAR *wrapperVersionRoot = TEXT("3.5.5");
-TCHAR *wrapperVersion = TEXT("3.5.5");
-TCHAR *wrapperBits = TEXT("32");
-TCHAR *wrapperArch = TEXT("x86");
-TCHAR *wrapperOS = TEXT("windows");
-TCHAR *wrapperReleaseDate = TEXT("20101004");
+TCHAR *wrapperVersionRoot = TEXT("3.5.19");
+TCHAR *wrapperVersion = TEXT("3.5.19");
+TCHAR *wrapperBits = TEXT("64");
+TCHAR *wrapperArch = TEXT("universal");
+TCHAR *wrapperOS = TEXT("macosx");
+TCHAR *wrapperReleaseDate = TEXT("20130419");
 TCHAR *wrapperReleaseTime = TEXT("0000");
-TCHAR *wrapperBuildDate = TEXT("20101004");
-TCHAR *wrapperBuildTime = TEXT("1657");
+TCHAR *wrapperBuildDate = TEXT("20130425");
+TCHAR *wrapperBuildTime = TEXT("1116");
 
